package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.AskLeave;
import com.zhaoliangsz.grainsearch.mapper.AskLeaveMapper;
import com.zhaoliangsz.grainsearch.service.IAskLeaveService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zyw
 * @since 2024-02-18 10:28:10
 */
@Slf4j
@Service
public class AskLeaveServiceImpl extends ServiceImpl<AskLeaveMapper, AskLeave> implements IAskLeaveService {
    @Override
    public PageResult<AskLeave> queryAskLeaveList(AskLeave queryAskLeave) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(queryAskLeave.getCurrentPage()-1)
            *queryAskLeave.getPageSize());
            pageView.put("pageSize",queryAskLeave.getPageSize());
            pageView.put("currentPage",queryAskLeave.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<AskLeave>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[AskLeaveServiceImpl.queryAskLeaveList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addAskLeave(AskLeave addAskLeave) throws ServiceException {
        boolean flag = this.save(addAskLeave);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editAskLeave(AskLeave editAskLeave) throws ServiceException {
        boolean flag = this.updateById(editAskLeave);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteAskLeave(AskLeave deleteAskLeave) throws ServiceException {
        boolean flag = this.removeById(deleteAskLeave);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
